@@ -504,11 +504,12 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 		    FROM jos_xgroups_members m 
 		    JOIN jos_xprofiles p on (p.uidNumber = m.uidNumber) 
 		    JOIN jos_xgroups g on (g.gidNumber = m.gidNumber)
-		    WHERE g.cn = %s"""
+		    WHERE g.cn = %s AND p.username NOT LIKE '-%%'"""
 			data = [dgroup.cn]
 			
 			for userGroupMembership in db.query(sql, data):
-				groupMembers.append(str(userGroupMembership.username))
+				if str(userGroupMembership.username) not in groupMembers:
+					groupMembers.append(str(userGroupMembership.username))
 
 		try:
 			print "syncing group '" + dgroup.cn + "' to ldap"
